Package: rYWAASB
Type: Package
Title: Simultaneous Selection by Trait and WAASB Index
Version: 0.4.1
Date: 2026-07-10.
Authors@R: 
    person(family="Arminian", given ="Ali", email="abeyran@gmail.com", role = c("aut", "cre", "cph"), comment = c(ORCID = "0000-0003-4749-6085"))
Maintainer: Ali Arminian <abeyran@gmail.com>
Description: This tool proposes a new ranking algorithm that utilizes a "Y*WAASB" biplot generated by the 'metan'. The aim of the current package is to effectively distinguish the top-ranked genotypes in MET (Multi-Environmental Trials). For a detailed explanation of the process of obtaining "WAASB", "WAASBY" indices, and a "Y*WAASB" biplot, refer to the manual included in this package as well as the study by Olivoto & Lúcio (2020) <doi:10.1111/2041-210X.13384>. In this context, "WAASB" refers to the "Weighted Average of Absolute Scores" provided by Olivoto et al. (2019) <doi:10.2134/agronj2019.03.0220>, which quantifies the stability of genotypes across different environments using linear mixed-effect models. To run the package, you need to extract the "WAASB" and "WAASBY" coefficients using the 'metan' and apply them. This tool utilizes PCA (Principal Component Analysis) and differentiates the entries which may be genotypes, hybrids, varieties, etc using "WAASB", "WAASBY", and a combination of the specified trait and WAASB index.
License: GPL-3
URL: https://github.com/abeyran/rYWAASB
BugReports: https://github.com/abeyran/rYWAASB/issues
Depends: R (>= 3.5)
Imports: ggplot2 (>= 3.3.0), graphics, factoextra, FactoMineR, mathjaxr
        (>= 2.0-0)
Suggests: car, metan, devtools, usethis, testthat, knitr, rmarkdown,
        roxygen2, spelling
VignetteBuilder: knitr
BuildManual: TRUE
RdMacros: mathjaxr
Encoding: UTF-8
Copyright: Ali Arminian
RoxygenNote: 8.0.0
Language: en-US
LazyData: true
LazyLoad: true
NeedsCompilation: no
Author: Ali Arminian [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-4749-6085>)
Packaged: 2026-07-10 09:54:03 UTC; A.Armin
Repository: CRAN
Date/Publication: 2026-07-12 07:40:02 UTC
Built: R 4.6.1; ; 2026-07-12 10:27:01 UTC; unix
