# Generated by roxygen2: do not edit by hand

export(PCA_biplot)
export(bar_plot1)
export(bar_plot2)
export(nbclust)
export(ranki)
import(ggplot2)
importFrom(FactoMineR,PCA)
importFrom(factoextra,fviz_eig)
importFrom(factoextra,fviz_nbclust)
importFrom(factoextra,fviz_pca_biplot)
importFrom(factoextra,get_eigenvalue)
importFrom(factoextra,get_pca_var)
importFrom(factoextra,hcut)
importFrom(graphics,barplot)
importFrom(graphics,par)
importFrom(graphics,text)
importFrom(stats,setNames)
